# Table of Contents

- [architecture-decision-templates](<./architecture-decision-templates.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Architecture Decision Templates](<./Architecture-Decision-Templates.md>)
  - [Overview](<./Architecture-Decision-Templates/Overview.md>)
  - [Template Components](<./Architecture-Decision-Templates/Template-Components.md>)
  - [Creating a Template](<./Architecture-Decision-Templates/Creating-a-Template.md>)
  - [Managing Templates](<./Architecture-Decision-Templates/Managing-Templates.md>)
  - [ID Prefixes](<./Architecture-Decision-Templates/ID-Prefixes.md>)
  - [Permissions](<./Architecture-Decision-Templates/Permissions.md>)
  - [Best Practices](<./Architecture-Decision-Templates/Best-Practices.md>)
  - [Was this page helpful?](<./Architecture-Decision-Templates/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./Architecture-Decision-Templates/Wed-love-your-feedback.md>)
